@@ -5,6 +5,18 @@ from docutils.writers.html4css1 import Writer
 
 from . import settings
 
+from .directives import exported_directives
+
+# Load the directives we can find.
+for directive_name in exported_directives :
+    try :
+        import_object = __import__(
+            'rip.directives.' + directive_name,
+            fromlist = ['core']
+        )
+    except ImportError :
+        pass
+
 def render(text, **kwargs) :
     '''Render a piece of ReStructuredText as HTML.'''
 
